{ pkgs
, ...
}:
{
  imports = [
    ./services/openssh.nix
    ./services/misc.nix
    ./modules/git.nix
    ./modules/nix-settings.nix
    ./modules/zfs.nix

    (import ./modules/networking.nix { hostname = "server"; })
    (import ./modules/users.nix { main-user = "baritone"; })
  ];

  boot.loader = {
    systemd-boot.enable = true;
    efi.canTouchEfiVariables = true;
    timeout = 0;
  };

  programs.zsh = {
    enable = true;
    enableGlobalCompInit = true;
  };

  programs.ssh.startAgent = true;
  programs.nano.enable = false;

  environment.systemPackages = with pkgs; [
    wget
    curl
    git
    vim
  ];

  environment.variables = {
    EDITOR = "vim";
  };

  time.timeZone = "Europe/Copenhagen";

  security.sudo = {
    enable = true;
    extraConfig = ''
      Defaults  lecture = never
    '';
  };

  programs.mtr.enable = true;
  programs.gnupg.agent.enable = true;

  system.stateVersion = "24.11";
}
